@@ -208,7 +208,7 @@ FAKE_DATA = {
     'container_inspect': {
         'Config': {
             'Env': ['KOLLA_BASE_DISTRO=ubuntu',
-                    'KOLLA_INSTALL_TYPE=binary',
+                    'KOLLA_INSTALL_TYPE=source',
                     'KOLLA_INSTALL_METATYPE=rdo'],
             'Hostname': 'node2',
             'Volumes': {'/var/lib/kolla/config_files/': {}}},
@@ -680,7 +680,7 @@ class TestContainer(base.BaseTestCase):
 
     def test_get_container_env(self):
         fake_env = dict(KOLLA_BASE_DISTRO='ubuntu',
-                        KOLLA_INSTALL_TYPE='binary',
+                        KOLLA_INSTALL_TYPE='source',
                         KOLLA_INSTALL_METATYPE='rdo')
         self.dw = get_DockerWorker({'name': 'my_container',
                                     'action': 'get_container_env'})
@@ -1348,12 +1348,12 @@ class TestAttrComp(base.BaseTestCase):
         container_info = {'Config': dict(
             Env=['KOLLA_CONFIG_STRATEGY=COPY_ALWAYS',
                  'KOLLA_BASE_DISTRO=ubuntu',
-                 'KOLLA_INSTALL_TYPE=binary']
+                 'KOLLA_INSTALL_TYPE=source']
         )}
         self.dw = get_DockerWorker({
             'environment': dict(KOLLA_CONFIG_STRATEGY='COPY_ALWAYS',
                                 KOLLA_BASE_DISTRO='ubuntu',
-                                KOLLA_INSTALL_TYPE='binary')})
+                                KOLLA_INSTALL_TYPE='source')})
 
         self.assertFalse(self.dw.compare_environment(container_info))
 
@@ -1361,12 +1361,12 @@ class TestAttrComp(base.BaseTestCase):
         container_info = {'Config': dict(
             Env=['KOLLA_CONFIG_STRATEGY=COPY_ALWAYS',
                  'KOLLA_BASE_DISTRO=ubuntu',
-                 'KOLLA_INSTALL_TYPE=binary']
+                 'KOLLA_INSTALL_TYPE=source']
         )}
         self.dw = get_DockerWorker({
             'environment': dict(KOLLA_CONFIG_STRATEGY='COPY_ALWAYS',
                                 KOLLA_BASE_DISTRO='centos',
-                                KOLLA_INSTALL_TYPE='binary')})
+                                KOLLA_INSTALL_TYPE='source')})
 
         self.assertTrue(self.dw.compare_environment(container_info))
 
